==> nui_form-0.0.14.tar.gz: lib/component/nuif_custom.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';

class NUIFCustomItem extends NUIFormComponent{
  NUIFCustomItem({
    @required String inpId,
    @required this.item,
    double width,
    double height,
    double weight,
    EdgeInsets margin,
    Alignment align
  }): super(inpId : inpId, inpType: ComponentType.CUSTOM, width: width, height: height, weight: weight, margin: margin, align: align);
  Widget item;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFCustomLayout(item: this, key: key, allButtonClickListener: allButtonClickListener, allTextChangeListener: allTextChangeListener,);
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
  }

  @override
  bool validate(bool quiet){
    return true;
  }
}

class NUIFCustomLayout extends StatefulWidget {
  NUIFCustomLayout({@required this.item, this.allTextChangeListener, this.allButtonClickListener, Key key}): super(key: key);
  final NUIFCustomItem item;
  final AllTextChangeListener allTextChangeListener;
  final AllButtonClickListener allButtonClickListener;

  @override
  _NUIFCustomLayoutState createState() => _NUIFCustomLayoutState();
}

class _NUIFCustomLayoutState extends NUIFState<NUIFCustomLayout, NUIFCustomItem> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _renderComponent(NUIFormComponent comp){
    return Container(
      child: item.item,
      width: comp.width,
      height: comp.height,
    );
  }

  @override
  Widget build(BuildContext context) {
    return item.wrapWidget(_renderComponent(item));
  }
}

==> nui_form-0.0.52.tar.gz: lib/component/nuif_custom.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';

class NUIFCustomItem extends NUIFormComponent{
  NUIFCustomItem({
    @required String inpId,
    @required this.item,
    double width,
    double height,
    double weight,
    EdgeInsets margin,
    Alignment align,
    bool show: true,
  }): super(inpId : inpId, inpType: ComponentType.CUSTOM, width: width, show: show,height: height, weight: weight, margin: margin, align: align);
  Widget item;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFCustomLayout(item: this, key: key, allButtonClickListener: allButtonClickListener, allTextChangeListener: allTextChangeListener,);
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
  }

  @override
  bool validate(bool quiet){
    return true;
  }
}

class NUIFCustomLayout extends StatefulWidget {
  NUIFCustomLayout({@required this.item, this.allTextChangeListener, this.allButtonClickListener, Key key}): super(key: key);
  final NUIFCustomItem item;
  final AllTextChangeListener allTextChangeListener;
  final AllButtonClickListener allButtonClickListener;

  @override
  _NUIFCustomLayoutState createState() => _NUIFCustomLayoutState();
}

class _NUIFCustomLayoutState extends NUIFState<NUIFCustomLayout, NUIFCustomItem> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _renderComponent(NUIFormComponent comp){
    return Container(
      child: item.item,
      width: comp.width,
      height: comp.height,
    );
  }

  @override
  Widget build(BuildContext context) {
    return item.wrapWidget(_renderComponent(item));
  }
}
